/**
 * @hidden
 * @returns {Promise<Object<string, string>>} Promise
 */
export function getLocalePromise(): Promise<{
    [x: string]: string;
}>;
/**
 * @hidden
 * @returns {Promise<(TileLayer<import('ol/source/Tile').default>|ImageLayer<import('ol/source/Image').default>|GroupLayer)[]>} Promise
 */
export function getBackgroundLayers(): Promise<(TileLayer<import("ol/source/Tile").default> | ImageLayer<import("ol/source/Image").default> | GroupLayer)[]>;
/**
 * @hidden
 * @returns {Promise<Map<string, overlayDefinition>>} Promise
 */
export function getOverlayDefs(): Promise<Map<string, overlayDefinition>>;
/**
 * @param {import('gmf/themes').GmfGroup|import('gmf/themes').GmfLayer|import('gmf/themes').GmfTheme} config Config
 * @param {import('gmf/themes').GmfOgcServers} ogcServers OGC servers
 * @param {import('gmf/themes').GmfOgcServer} [opt_ogcServer] OGC server
 * @hidden
 */
export function writeOverlayDefs(config: import("gmf/themes").GmfGroup | import("gmf/themes").GmfLayer | import("gmf/themes").GmfTheme, ogcServers: import("gmf/themes").GmfOgcServers, opt_ogcServer?: import("gmf/themes").GmfOgcServer): void;
/**
 * Returns a list of OpenLayers layer objects from the given layer names.
 *
 * @param {string[]} layerNames List of layer names
 * @returns {Promise<(TileLayer<import('ol/source/Tile').default>|ImageLayer<import('ol/source/Image').default>)[]>} Promise.
 * @hidden
 */
export function getOverlayLayers(layerNames: string[]): Promise<(TileLayer<import("ol/source/Tile").default> | ImageLayer<import("ol/source/Image").default>)[]>;
/**
 * @param {import('gmf/themes').GmfLayerWMS} config Layer config (i.e. gmf layer node)
 * @param {import('gmf/themes').GmfOgcServer} ogcServer OGC server configuration used to create the layer.
 * @returns {Promise<ImageLayer<import('ol/source/Image').default>>} Promise.
 * @hidden
 */
export function createWMSLayer(config: import("gmf/themes").GmfLayerWMS, ogcServer: import("gmf/themes").GmfOgcServer): Promise<ImageLayer<import("ol/source/Image").default>>;
/**
 * @param {import('gmf/themes').GmfLayerWMTS} config Layer config (i.e. gmf layer node)
 * @returns {Promise<?TileLayer<import('ol/source/Tile').default>>} Promise.
 * @hidden
 */
export function createWMTSLayer(config: import("gmf/themes").GmfLayerWMTS): Promise<TileLayer<import("ol/source/Tile").default> | null>;
export type overlayDefinition = {
    layer: import("gmf/themes").GmfLayer;
    ogcServer: import("gmf/themes").GmfOgcServer;
};
import TileLayer from 'ol/layer/WebGLTile';
import ImageLayer from 'ol/layer/Image';
import GroupLayer from 'ol/layer/Group';
