/**
 * @classdesc
 * Events emitted by {@link module:ol/interaction/Select~Select} instances are instances of
 * this type.
 */
export class SelectEvent extends Event {
    /**
     * @param {string} type The event type.
     * @param {Array<import("ol/Feature.js").default<import('ol/geom/Geometry.js').default>>} selected Selected features.
     * @param {Array<import("ol/Feature.js").default<import('ol/geom/Geometry.js').default>>} deselected Deselected features.
     * @param {import("ol/MapBrowserEvent.js").default<unknown>} mapBrowserEvent Associated
     *     {@link module:ol/MapBrowserEvent}.
     */
    constructor(type: string, selected: Array<import("ol/Feature.js").default<import("ol/geom/Geometry.js").default>>, deselected: Array<import("ol/Feature.js").default<import("ol/geom/Geometry.js").default>>, mapBrowserEvent: import("ol/MapBrowserEvent.js").default<unknown>);
    /**
     * Selected features array.
     *
     * @type {Array<import("ol/Feature.js").default<import('ol/geom/Geometry.js').default>>}
     * @api
     */
    selected: Array<import("ol/Feature.js").default<import("ol/geom/Geometry.js").default>>;
    /**
     * Deselected features array.
     *
     * @type {Array<import("ol/Feature.js").default<import('ol/geom/Geometry.js').default>>}
     * @api
     */
    deselected: Array<import("ol/Feature.js").default<import("ol/geom/Geometry.js").default>>;
    /**
     * Associated {@link module:ol/MapBrowserEvent}.
     *
     * @type {import("ol/MapBrowserEvent.js").default<unknown>}
     * @api
     */
    mapBrowserEvent: import("ol/MapBrowserEvent.js").default<unknown>;
}
import Event from 'ol/events/Event.js';
