/**
 * Desktop application abstract controller.
 *
 * This file includes `import`'s for desktop components/directives used
 * by the HTML page and the controller to provide the configuration.
 */
export class AbstractDesktopController extends AbstractAPIController {
    /**
     * @type {boolean}
     */
    queryGrid: boolean;
    /**
     * To toggle the activation query grid in the HTML, shouldn't be touch (it's managed by angular).
     *
     * @type {boolean}
     */
    queryGridActive: boolean;
    /**
     * @type {boolean}
     */
    dataPanelActive: boolean;
    /**
     * @type {boolean}
     */
    toolsActive: boolean;
    /**
     * @type {boolean}
     */
    modalShareShown: boolean;
    /**
     * @type {boolean}
     */
    editFeatureActive: boolean;
    /**
     * @type {boolean}
     */
    queryPanelActive: boolean;
    /**
     * @type {boolean}
     */
    googleStreetViewActive: boolean;
    /**
     * @type {boolean}
     */
    mapillaryStreetViewActive: boolean;
    /**
     * Set the clearing of the ngeoQuery after the deactivation of the query
     *
     * @type {boolean}
     */
    queryAutoClear: boolean;
    /**
     * @type {boolean}
     */
    contextdataActive: boolean;
    /**
     * @type {boolean}
     */
    printPanelActive: boolean;
    /**
     * @type {boolean}
     */
    printActive: boolean;
    /**
     * @type {boolean}
     */
    drawFeatureActive: boolean;
    /**
     * @type {boolean}
     */
    drawProfilePanelActive: boolean;
    /**
     * @type {boolean}
     */
    routingPanelActive: boolean;
    editFeatureActivate: boolean;
    toolsPanelWidth: number;
    /**
     * @type {import('ol/style/Style').default}
     */
    streetViewStyle: import("ol/style/Style").default;
    /**
     * @type {boolean}
     */
    importDataSourceActive: boolean;
    /**
     * @type {import('ol/layer/Vector').default<import('ol/source/Vector').default<import('ol/geom/Geometry').default>>}
     */
    editFeatureVectorLayer: import("ol/layer/Vector").default<import("ol/source/Vector").default<import("ol/geom/Geometry").default>>;
    /**
     * The ngeo ToolActivate manager service.
     *
     * @type {import('ngeo/misc/ToolActivateMgr').ToolActivateMgr}
     */
    ngeoToolActivateMgr: import("ngeo/misc/ToolActivateMgr").ToolActivateMgr;
    /**
     * @type {import('gmf/datasource/DataSourceBeingFiltered').DataSourceBeingFiltered}
     */
    gmfDataSourceBeingFiltered: import("gmf/datasource/DataSourceBeingFiltered").DataSourceBeingFiltered;
    /**
     * The gmf layer being swipe.
     *
     * @type {import('gmf/datasource/LayerBeingSwipe').LayerBeingSwipe}
     */
    gmfLayerBeingSwipe: import("gmf/datasource/LayerBeingSwipe").LayerBeingSwipe;
    /**
     * @type {?import('ol/geom/LineString').default}
     */
    profileLine: import("ol/geom/LineString").default | null;
    /**
     * @type {number}
     * @private
     */
    private dataPanelMinResizableWidth_;
    /**
     * @type {number}
     * @private
     */
    private toolsPanelMinResizableWidth_;
    /**
     * @type {number}
     * @private
     */
    private dataPanelWidth_;
    /**
     * @type {number}
     * @private
     */
    private appBarWidth_;
    /**
     * @type {number}
     * @private
     */
    private minimumMapWidth_;
    /**
     * @type {number}
     * @private
     */
    private streetViewWidth_;
    /**
     * @type {JQuery}
     * @private
     */
    private $dataPanel_;
    /**
     * @type {JQuery}
     * @private
     */
    private $toolsPanel_;
    drawLidarprofilePanelActive: boolean;
    /**
     * Set the data panel (on the left) maximum resizable width depending
     * on the current size of the window, taking into consideration the
     * width the right panel can have.
     *
     * If, after resizing, the size of the data panel would be too big,
     * resize it as well.
     *
     * @param {number} [opt_newToolsPanelWidth]
     * @private
     * @hidden
     */
    private setDataPanelMaxResizableWidth_;
    /**
     * Set the tools panel (on the right) maximum resizable width depending
     * on the current size of the window, taking into consideration the
     * width the left panel has.
     *
     * If, after resizing, the size of the data panel would be too big,
     * resize it as well.
     *
     * @param {number} [opt_newDataPanelWidth]
     * @private
     * @hidden
     */
    private setToolsPanelMaxResizableWidth_;
    /**
     * Check if the panel size is not exceeding its maximum allowed and
     * resize it to present maxSize if necessary
     *
     * @param {number} panelSize
     * @param {JQuery} panelToResize
     * @returns {number}
     * @private
     * @hidden
     */
    private checkPanelWidth_;
    /**
     * Get the new maximum size for the other panel
     *
     * @param {JQuery} resizedPanel
     * @param {number} otherPanelMinResizableWidth
     * @param {number} newPanelWidth
     * @returns {number}
     * @private
     * @hidden
     */
    private findMaxWidth_;
}
export namespace AbstractDesktopController {
    let $inject: string[];
}
export default myModule;
import { AbstractAPIController } from 'gmf/controllers/AbstractAPIController';
/**
 * @type {angular.IModule}
 * @hidden
 */
declare const myModule: angular.IModule;
import angular from 'angular';
