/**
 * Mobile application abstract controller.
 *
 * This file includes `import`'s mobile components/directives used
 * by the HTML page and the controller to provide the configuration.
 */
export class AbstractMobileController extends AbstractAppController {
    /**
     * @param {angular.IScope} $scope Scope.
     * @param {angular.auto.IInjectorService} $injector Main injector.
     */
    constructor($scope: angular.IScope, $injector: angular.auto.IInjectorService);
    /**
     * @type {boolean}
     */
    leftNavVisible: boolean;
    /**
     * @type {boolean}
     */
    rightNavVisible: boolean;
    /**
     * @type {boolean}
     */
    searchOverlayVisible: boolean;
    /**
     * The active state of the directive responsible of area measurements.
     *
     * @type {boolean}
     */
    measureAreaActive: boolean;
    /**
     * The active state of the directive responsible of point measurements.
     *
     * @type {boolean}
     */
    measurePointActive: boolean;
    /**
     * The active state of the directive responsible of length measurements.
     *
     * @type {boolean}
     */
    measureLengthActive: boolean;
    /**
     * @constant {string}
     */
    redirectUrl: any;
    /**
     */
    toggleLeftNavVisibility(): void;
    /**
     */
    toggleRightNavVisibility(): void;
    /**
     * Hide both navigation menus.
     */
    hideNav(): void;
    /**
     * @returns {boolean} Return true if one of the navigation menus is visible,
     * otherwise false.
     */
    navIsVisible(): boolean;
    /**
     * Open the menu with corresponding to the data-target attribute value.
     *
     * @param {string} target the data-target value.
     */
    openNavMenu(target: string): void;
}
export namespace AbstractMobileController {
    let $inject: string[];
}
export default myModule;
import { AbstractAppController } from 'gmf/controllers/AbstractAppController';
import angular from 'angular';
/**
 * @type {angular.IModule}
 * @hidden
 */
declare const myModule: angular.IModule;
