export default ArcGISGeoJSON;
/**
 * // Properties for ArcGISGeoJSON
 */
export type Options = {
    /**
     * If set, only features of the given layers will be returned by the format when read.
     * // Properties from GeoJSON
     */
    layers?: string[];
    /**
     * Default data projection.
     */
    dataProjection?: import("ol/proj").ProjectionLike;
    /**
     * Projection for features read or
     * written by the format.  Options passed to read or write methods will take precedence.
     */
    featureProjection?: import("ol/proj").ProjectionLike;
    /**
     * Geometry name to use when creating features.
     */
    geometryName?: string;
    /**
     * Certain GeoJSON providers include
     * the geometry_name field in the feature GeoJSON. If set to `true` the GeoJSON reader
     * will look for that field to set the geometry name. If both this field is set to `true`
     * and a `geometryName` is provided, the `geometryName` will take precedence.
     */
    extractGeometryName?: boolean;
};
declare class ArcGISGeoJSON extends olFormatGeoJSON<import("ol/Feature").default<import("ol/geom/Geometry").default>> {
    /**
     * @param {Options} [opt_options] Options.
     */
    constructor(opt_options?: Options);
    /**
     * @private
     * @type {string[]}
     */
    private layers_;
    /**
     * @returns {string[]} layers
     */
    getLayers(): string[];
    /**
     * @param {string[]} layers Layers to parse.
     */
    setLayers(layers: string[]): void;
    /**
     * @param {import("geojson").GeoJSON} object Object.
     * @param {import('ol/format/Feature').ReadOptions} [opt_options] Read options.
     * @protected
     * @returns {import('ol/Feature').default<import('ol/geom/Geometry').default>[]} Features.
     * @override
     */
    protected override readFeaturesFromObject(object: import("geojson").GeoJSON, opt_options?: import("ol/format/Feature").ReadOptions): import("ol/Feature").default<import("ol/geom/Geometry").default>[];
}
import olFormatGeoJSON from 'ol/format/GeoJSON';
