/**
 * Creates a `<PropertyIsBetween>` comparison operator to test whether a property
 * value lies within a time range given by a lower and upper bound (inclusive).
 *
 * @param {!string} propertyName Name of the context property to compare.
 * @param {!string} lowerBoundary The lower bound of the range.
 * @param {!string} upperBoundary The upper bound of the range.
 * @returns {!DateIsBetween} `<PropertyIsBetween>` operator.
 */
export function dateBetween(propertyName: string, lowerBoundary: string, upperBoundary: string): DateIsBetween;
/**
 * @classdesc
 * Represents a `<PropertyIsBetween>` temporal comparison operator,
 * suitable for QGIS server that does not support `<During>`.
 */
export class DateIsBetween extends olFormatFilterComparison {
    /**
     * @param {!string} propertyName Name of the context property to compare.
     * @param {!string} lowerBoundary The lower bound of the range.
     * @param {!string} upperBoundary The upper bound of the range.
     */
    constructor(propertyName: string, lowerBoundary: string, upperBoundary: string);
    /**
     * @type {!string}
     */
    lowerBoundary: string;
    /**
     * @type {!string}
     */
    upperBoundary: string;
}
import olFormatFilterComparison from 'ol/format/filter/Comparison';
