/**
 * @param {angular.IScope} $scope Angular scope.
 * @class
 * @private
 * @hidden
 * @ngdoc controller
 * @ngname ngeoGridController
 */
export function GridController($scope: angular.IScope): void;
export class GridController {
    /**
     * @param {angular.IScope} $scope Angular scope.
     * @class
     * @private
     * @hidden
     * @ngdoc controller
     * @ngname ngeoGridController
     */
    private constructor();
    /**
     * @type {angular.IScope}
     */
    scope_: angular.IScope;
    /**
     * @type {?import('ngeo/grid/Config').default}
     */
    configuration: import("ngeo/grid/Config").default | null;
    /**
     * @type {Object<string, Object>}
     */
    selectedRows: {
        [x: string]: Object;
    };
    /**
     * The name of the column used to sort the grid.
     *
     * @type {string}
     */
    sortedBy: string;
    /**
     * @type {boolean}
     */
    sortAscending: boolean;
    /**
     * Configuration object for float-thead.
     *
     * @type {unknown}
     */
    floatTheadConfig: unknown;
    /**
     * Init the controller
     */
    $onInit(): void;
    /**
     * Sort function that always puts undefined values to the bottom of the grid.
     * A new call will sort ascending. A next one will sort descending (and so
     * on).
     *
     * @param {string} columnName The name of the column that should be used to
     *    sort the data.
     */
    sort(columnName: string): void;
    /**
     * Handler for clicks on a row.
     *
     * @param {unknown} attributes An entry/row.
     * @param {JQuery.Event} event Event.
     */
    clickRow(attributes: unknown, event: JQuery.Event): void;
    /**
     * @param {unknown} attributes An entry/row.
     * @param {boolean} shiftKey Shift pressed?
     * @param {boolean} platformModifierKey CTRL/Meta pressed?
     */
    clickRow_(attributes: unknown, shiftKey: boolean, platformModifierKey: boolean): void;
    /**
     * Selects all rows between the given row and the closest already selected row.
     *
     * @param {unknown} attributes An entry/row.
     */
    selectRange_(attributes: unknown): void;
    /**
     * Prevent the default browser behavior of selecting text
     * when selecting multiple rows with SHIFT or CTRL/Meta.
     *
     * @param {JQuery.Event} event Event.
     */
    preventTextSelection(event: JQuery.Event): void;
}
export namespace GridController {
    let $inject: string[];
}
export default myModule;
import angular from 'angular';
/**
 * @type {angular.IModule}
 * @hidden
 */
declare const myModule: angular.IModule;
