export default DrawAzimut;
export type Options = {
    source: VectorSource<import("ol/geom/Geometry").default>;
    style: import("ol/style/Style").StyleLike;
};
/**
 * @typedef {Object} Options
 * @property {!VectorSource<import('ol/geom/Geometry').default>} source
 * @property {import('ol/style/Style').StyleLike} style
 */
/**
 * Interaction dedicated to measure azimut.
 *
 * @private
 * @hidden
 */
declare class DrawAzimut extends olInteractionPointer {
    /**
     * @param {Options} options Options.
     */
    constructor(options: Options);
    shouldStopEvent: typeof FALSE;
    /**
     * Whether the drawing has started or not.
     *
     * @type {boolean}
     * @private
     */
    private started_;
    /**
     * Vector layer where our sketch features are drawn.
     *
     * @type {import('ol/layer/Vector').default<import('ol/source/Vector').default<import('ol/geom/Geometry').default>>}
     * @private
     */
    private sketchLayer_;
    /**
     * Handle move events.
     *
     * @param {import('ol/MapBrowserEvent').default<unknown>} event MapBrowserEvent, a move event.
     * @returns {boolean} Pass the event to other interactions.
     * @private
     */
    private handlePointerMove_;
    /**
     * @param {import('ol/MapBrowserEvent').default<unknown>} event MapBrowserEvent.
     * @private
     */
    private createOrUpdateSketchPoint_;
    /**
     * Redraw the sketch features.
     *
     * @private
     */
    private updateSketchFeatures_;
    /**
     * Start the drawing.
     *
     * @param {import('ol/MapBrowserEvent').default<unknown>} event MapBrowserEvent.
     * @private
     */
    private startDrawing_;
    /**
     * Modify the drawing.
     *
     * @param {import('ol/MapBrowserEvent').default<unknown>} event MapBrowserEvent.
     * @private
     */
    private modifyDrawing_;
    /**
     * Stop drawing without adding the sketch feature to the target layer.
     *
     * @returns {Feature<import('ol/geom/Geometry').default>} The sketch feature (or null if none).
     * @private
     */
    private abortDrawing_;
    /**
     * @private
     */
    private updateState_;
    /**
     * Stop drawing and add the sketch feature to the target layer.
     *
     * @private
     */
    private finishDrawing_;
    /**
     * @param {import('ol/MapBrowserEvent').default<unknown>} event MapBrowserEvent.
     * @returns {boolean} If the event was consumed.
     */
    handleDownEvent(event: import("ol/MapBrowserEvent").default<unknown>): boolean;
    /**
     * @param {import('ol/MapBrowserEvent').default<unknown>} event MapBrowserEvent.
     * @returns {boolean} If the event was consumed.
     */
    handleUpEvent(event: import("ol/MapBrowserEvent").default<unknown>): boolean;
    /**
     * @param {import('ol/MapBrowserEvent').default<unknown>} mapBrowserEvent MapBrowserEvent.
     * @returns {boolean} If the event was consumed.
     */
    handleEvent(mapBrowserEvent: import("ol/MapBrowserEvent").default<unknown>): boolean;
}
import VectorSource from 'ol/source/Vector';
import olInteractionPointer from 'ol/interaction/Draw';
import { FALSE } from 'ol/functions';
