/**
 * Compute azimut from a 2 points line.
 *
 * @param {import('ol/geom/LineString').default} line LineString.
 * @returns {number} Azimut value.
 * @hidden
 */
export function getAzimut(line: import("ol/geom/LineString").default): number;
/**
 * Format measure output of azimut.
 *
 * @param {import('ol/geom/LineString').default} line LineString.
 * @param {number|undefined} decimals Decimals.
 * @param {import('ngeo/misc/filters').formatNumber} format The format function.
 * @returns {string} Formatted measure.
 * @hidden
 */
export function getFormattedAzimut(line: import("ol/geom/LineString").default, decimals: number | undefined, format: import("ngeo/misc/filters").formatNumber): string;
/**
 * Format measure output of azimut and radius.
 *
 * @param {import('ol/geom/LineString').default} line LineString.
 * @param {import('ol/proj/Projection').default} projection Projection of the polygon coords.
 * @param {number|undefined} decimals Decimals.
 * @param {number|undefined} precision Precision.
 * @param {import('ngeo/misc/filters').unitPrefix} formatLength The format function.
 * @param {import('ngeo/misc/filters').formatNumber} formatAzimut The format function.
 * @returns {string} Formatted measure.
 * @hidden
 */
export function getFormattedAzimutRadius(line: import("ol/geom/LineString").default, projection: import("ol/proj/Projection").default, decimals: number | undefined, precision: number | undefined, formatLength: import("ngeo/misc/filters").unitPrefix, formatAzimut: import("ngeo/misc/filters").formatNumber): string;
/**
 * Interaction dedicated to measure length.
 *
 * See our live example: [../examples/measure.html](../examples/measure.html)
 */
export default class _default extends ngeoInteractionMeasure {
    /**
     * @fires import('ngeo/interaction/Measure').MeasureEvent
     * @param {import('ngeo/misc/filters').unitPrefix} unitPrefixFormat The format function
     * @param {import('ngeo/misc/filters').formatNumber} numberFormat The format function
     * @param {import('ngeo/interaction/Measure').MeasureOptions} [options] Options
     */
    constructor(unitPrefixFormat: import("ngeo/misc/filters").unitPrefix, numberFormat: import("ngeo/misc/filters").formatNumber, options?: import("ngeo/interaction/Measure").MeasureOptions);
    /**
     * The format function
     *
     * @type {import('ngeo/misc/filters').formatNumber}
     */
    numberFormat: import("ngeo/misc/filters").formatNumber;
    /**
     * The format function
     *
     * @type {import('ngeo/misc/filters').unitPrefix}
     */
    unitPrefixFormat: import("ngeo/misc/filters").unitPrefix;
    /**
     * @param {import('ol/style/Style').StyleLike} style The sketchStyle used for the drawing
     *    interaction.
     * @param {import('ol/source/Vector').default<import('ol/geom/LineString').default>} source Vector source.
     * @returns {?import('ol/interaction/Draw').default|import('ngeo/interaction/DrawAzimut').default|
     *    import('ngeo/interaction/MobileDraw').default} The interaction
     */
    createDrawInteraction(style: import("ol/style/Style").StyleLike, source: import("ol/source/Vector").default<import("ol/geom/LineString").default>): (import("ol/interaction/Draw").default | import("ngeo/interaction/DrawAzimut").default | import("ngeo/interaction/MobileDraw").default) | null;
}
import ngeoInteractionMeasure from 'ngeo/interaction/Measure';
