/**
 * Interaction dedicated to measure length.
 *
 * See our live example: [../examples/measure.html](../examples/measure.html)
 */
export default class _default extends ngeoInteractionMeasure {
    /**
     * @param {import('ngeo/misc/filters').unitPrefix} format The format function
     * @param {angular.gettext.gettextCatalog} gettextCatalog Gettext catalog.
     * @param {import('ngeo/interaction/Measure').MeasureOptions} [options] Options
     */
    constructor(format: import("ngeo/misc/filters").unitPrefix, gettextCatalog: angular.gettext.gettextCatalog, options?: import("ngeo/interaction/Measure").MeasureOptions);
    continueMsg: Element | HTMLSpanElement;
    /**
     * @type {boolean}
     */
    spherical: boolean;
    /**
     * The format function
     *
     * @type {import('ngeo/misc/filters').unitPrefix}
     */
    format: import("ngeo/misc/filters").unitPrefix;
    /**
     * The snapping tolerance in pixels.
     *
     * @type {number}
     */
    tolerance: number;
    /**
     * The snapping source
     *
     * @type {import('ol/source/Vector').default<*>}
     */
    source: import("ol/source/Vector").default<any>;
    /**
     * @param {import('ol/style/Style').StyleLike} style The sketchStyle used for the drawing
     *    interaction.
     * @param {import('ol/source/Vector').default<import('ol/geom/LineString').default>} source Vector source.
     * @returns {olInteractionDraw|import('ngeo/interaction/MobileDraw').default} The interaction
     */
    createDrawInteraction(style: import("ol/style/Style").StyleLike, source: import("ol/source/Vector").default<import("ol/geom/LineString").default>): olInteractionDraw | import("ngeo/interaction/MobileDraw").default;
    /**
     * Create a `linestringGeometryFunction` that will create a line string with segments
     * snapped to π/4 angle.
     * Use this with the draw interaction and `type: 'LineString'`.
     *
     * @param {number[][]} coordinates Coordinates.
     * @param {import('ol/geom/SimpleGeometry').default|undefined} [opt_geometry] Geometry.
     * @returns {import('ol/geom/SimpleGeometry').default} Geometry.
     */
    linestringGeometryFunction(coordinates: number[][], opt_geometry?: import("ol/geom/SimpleGeometry").default | undefined): import("ol/geom/SimpleGeometry").default;
    /**
     * Compute the intersection between 2 segments.
     *
     * @param {number[][]} line1 The coordinates of the first line.
     * @param {number[][]} line2 The coordinates of the second line.
     * @returns {number[] | undefined} The intersection point, undefined if there is no intersection point or lines are coincident.
     */
    computeLineSegmentIntersection(line1: number[][], line2: number[][]): number[] | undefined;
}
import ngeoInteractionMeasure from 'ngeo/interaction/Measure';
import olInteractionDraw from 'ol/interaction/Draw';
