/**
 * ngeo - WMS time service
 *
 * @ngdoc service
 * @ngname ngeoWMSTime
 * @hidden
 */
export class WMSTime extends Time {
    /**
     * @param {angular.IFilterService} $filter angular filter service.
     * @param {angular.gettext.gettextCatalog} gettextCatalog service.
     */
    constructor($filter: angular.IFilterService, gettextCatalog: angular.gettext.gettextCatalog);
    /**
     * @private
     * @type {angular.IFilterService}
     */
    private $filter_;
    /**
     * @type {angular.gettext.gettextCatalog}
     * @private
     */
    private gettextCatalog_;
    /**
     * Format time regarding a resolution
     *
     * @param  {number} time (in ms format) timestamp to format
     * @param  {import('ngeo/datasource/OGC').TimePropertyResolutionEnum|undefined} resolution resolution to
     *    use.
     * @param  {boolean} [opt_useISOFormat] True to a ISO-8601 date string that can be used
     *     as a WMS-T Parameter. Otherwise, use a localized date format.
     * @param  {boolean} [opt_toUTC] to get the UTC date
     * @returns {string} Date string regarding the resolution.
     */
    formatTimeValue(time: number, resolution: import("ngeo/datasource/OGC").TimePropertyResolutionEnum | undefined, opt_useISOFormat?: boolean, opt_toUTC?: boolean): string;
    /**
     * Format time to be used as a WMS Time query parameter
     *
     * @param  {import('ngeo/datasource/OGC').TimeProperty} wmsTimeProperty a wmstime property from a node
     * @param  {import('ngeo/datasource/OGC').TimeRange} times start & end time selected (in ms format)
     * @param  {boolean} [opt_toUTC] to get the UTC date
     * @returns {string} ISO-8601 date string ready to be used as a query parameter for a
     * WMS request
     */
    formatWMSTimeParam(wmsTimeProperty: import("ngeo/datasource/OGC").TimeProperty, times: import("ngeo/datasource/OGC").TimeRange, opt_toUTC?: boolean): string;
}
export namespace WMSTime {
    let $inject: string[];
}
export default myModule;
import { Time } from 'ngeo/misc/Time';
import angular from 'angular';
/**
 * @type {angular.IModule}
 * @hidden
 */
declare const myModule: angular.IModule;
