/**
 * @typedef {import('ol/coordinate').Coordinate} Coordinate
 */
/**
 * Convert a given coordinate or list of coordinates of any 'nesting' level
 * to XY, i.e. remove any extra dimensions to the coordinates and keep only 2.
 *
 * @param {Coordinate} coordinates Coordinates
 * @returns {Coordinate} Converted coordinates.
 * @hidden
 */
export function coordinatesToXY0(coordinates: Coordinate): Coordinate;
/**
 * Convert a given coordinate or list of coordinates of any 'nesting' level
 * to XY, i.e. remove any extra dimensions to the coordinates and keep only 2.
 *
 * @template {number|Coordinate|Coordinate[]|Coordinate[][]} T
 * @param {T[]} coordinates Coordinates
 * @param {number} nesting Nesting level.
 * @returns {T[]} Converted coordinates.
 * @hidden
 */
export function toXY<T extends number | Coordinate | Coordinate[] | Coordinate[][]>(coordinates: T[], nesting: number): T[];
/**
 * Convert a given coordinate or list of coordinates of any 'nesting' level
 * to XY, i.e. remove any extra dimensions to the coordinates and keep only 2.
 *
 * @param {Coordinate[]} coordinates Coordinates
 * @returns {Coordinate[]} Converted coordinates.
 * @hidden
 */
export function coordinatesToXY1(coordinates: Coordinate[]): Coordinate[];
/**
 * Convert a given coordinate or list of coordinates of any 'nesting' level
 * to XY, i.e. remove any extra dimensions to the coordinates and keep only 2.
 *
 * @param {Coordinate[][]} coordinates Coordinates
 * @returns {Coordinate[][]} Converted coordinates.
 * @hidden
 */
export function coordinatesToXY2(coordinates: Coordinate[][]): Coordinate[][];
/**
 * Convert a given coordinate or list of coordinates of any 'nesting' level
 * to XY, i.e. remove any extra dimensions to the coordinates and keep only 2.
 *
 * @param {Coordinate[][][]} coordinates Coordinates
 * @returns {Coordinate[][][]} Converted coordinates.
 * @hidden
 */
export function coordinatesToXY3(coordinates: Coordinate[][][]): Coordinate[][][];
export type Coordinate = import("ol/coordinate").Coordinate;
