export default exports;
export type Action = {
    id: number;
    plugin: string;
    command: string;
    args: any[];
    context: unknown;
    msg?: string;
};
/**
 * @typedef {Object} Action
 * @property {number} id
 * @property {string} plugin
 * @property {string} command
 * @property {!*[]} args
 * @property {?} context
 * @property {string} [msg]
 */
/**
 * @abstract
 */
declare const exports: {
    new (): {
        waitingPromises_: Map<any, any>;
        currentId_: number;
        /**
         * @param  {...unknown} args Some arguments.
         * @returns {Promise<void>}
         */
        setItem(...args: unknown[]): Promise<void>;
        /**
         * @param  {...unknown} args Some arguments.
         * @returns {Promise<void>}
         */
        getItem(...args: unknown[]): Promise<void>;
        /**
         * @returns {Promise<void>}
         */
        clear(): Promise<void>;
        /**
         * @param  {...unknown} args Some arguments.
         * @returns {Promise<void>}
         */
        config(...args: unknown[]): Promise<void>;
        /**
         * @export
         * @param {string} command .
         * @param  {...unknown} args .
         * @returns {Promise<void>} .
         */
        createAction(command: string, ...args: unknown[]): Promise<void>;
        /**
         * @export
         * @param {*} event .
         */
        receiveMessage(event: any): void;
        /**
         * @abstract
         * @protected
         * @param {Action} action .
         */
        postToBackend(action: Action): void;
    };
};
