export default ServiceManager;
declare class ServiceManager {
    /**
     * @param {angular.auto.IInjectorService} $injector Main injector.
     * @struct
     * @ngdoc service
     * @ngname ngeoOfflineServiceManager
     */
    constructor($injector: angular.auto.IInjectorService);
    /**
     * @type {angular.auto.IInjectorService}
     * @private
     */
    private $injector_;
    /**
     * @type {*}
     * @private
     */
    private saveService_;
    /**
     * @type {*}
     * @private
     */
    private restoreService_;
    /**
     * @param {string|unknown} serviceLike A service like.
     * @param {string} method A method.
     * @returns {unknown} A returned object.
     */
    getOfflineService_(serviceLike: string | unknown, method: string): unknown;
    /**
     * Set the service to call on 'save'.
     *
     * @param {string|{save: Function}} saveLikeService
     * A service name that can be injected or an object that have a 'save' method.
     */
    setSaveService(saveLikeService: string | {
        save: Function;
    }): void;
    /**
     * Set the service to call on 'restore'
     *
     * @param {string|{restore: Function}} restoreLikeService
     * A service name that can be injected or an object that have a 'restore' method.
     */
    setRestoreService(restoreLikeService: string | {
        restore: Function;
    }): void;
    cancel(): void;
    /**
     * Ask the provided service to save the data to an offline purpose
     *
     * @param {import('ol/extent').Extent} extent The extent to download.
     * @param {import("ol/Map").default} map The map to work on.
     */
    save(extent: import("ol/extent").Extent, map: import("ol/Map").default): void;
    /**
     * Ask the provided service to restore the saved data on the map
     *
     * @param {import('ol/Map').default} map The map to work on.
     * @returns {Promise<import('ol/extent').Extent>} A promise to the extent of the downloaded area
     */
    restore(map: import("ol/Map").default): Promise<import("ol/extent").Extent>;
}
declare namespace ServiceManager {
    let $inject: string[];
    let module: angular.IModule;
}
import angular from 'angular';
