export class Controller {
    /**
     * @param {angular.ITimeoutService} $timeout Angular timeout service.
     * @param {import('ngeo/offline/ServiceManager').default} ngeoOfflineServiceManager
     * ngeo offline service Manager.
     * @param {import('ngeo/offline/Configuration').default} ngeoOfflineConfiguration
     * ngeo offline configuration service.
     * @param {import('ngeo/offline/Mode').default} ngeoOfflineMode Offline mode manager.
     * @param {import('ngeo/offline/NetworkStatus').default} ngeoNetworkStatus ngeo network status service.
     * @ngdoc controller
     * @ngname ngeoOfflineController
     */
    constructor($timeout: angular.ITimeoutService, ngeoOfflineServiceManager: import("ngeo/offline/ServiceManager").default, ngeoOfflineConfiguration: import("ngeo/offline/Configuration").default, ngeoOfflineMode: import("ngeo/offline/Mode").default, ngeoNetworkStatus: {
        $document_: JQueryStatic;
        $window_: Window;
        $timeout_: angular.ITimeoutService;
        $rootScope_: angular.IScope;
        ngeoOfflineTestUrl_: import("../options").ngeoOfflineTestUrl;
        count_: number;
        offline_: boolean | undefined;
        promise_: angular.IPromise<void> | undefined;
        initialize_(): void;
        check(timeout?: number): void;
        triggerChangeStatusEvent_(offline: boolean): void;
        isDisconnected(): boolean;
    });
    /**
     * @type {angular.ITimeoutService}
     * @private
     */
    private $timeout_;
    /**
     * @private
     */
    private maskLayer_;
    /**
     * @type {import('ngeo/offline/ServiceManager').default}
     * @private
     */
    private ngeoOfflineServiceManager_;
    /**
     * @private
     * @type {import('ngeo/offline/Configuration').default}
     */
    private ngeoOfflineConfiguration_;
    /**
     * @type {import('ngeo/offline/Mode').default}
     * @export
     */
    offlineMode: import("ngeo/offline/Mode").default;
    /**
     * @type {import('ngeo/offline/NetworkStatus').default}
     * @export
     */
    networkStatus: {
        $document_: JQueryStatic;
        $window_: Window;
        $timeout_: angular.ITimeoutService;
        $rootScope_: angular.IScope;
        ngeoOfflineTestUrl_: import("../options").ngeoOfflineTestUrl;
        count_: number;
        offline_: boolean | undefined;
        promise_: angular.IPromise<void> | undefined;
        initialize_(): void;
        check(timeout?: number): void;
        triggerChangeStatusEvent_(offline: boolean): void;
        isDisconnected(): boolean;
    };
    /**
     * The map.
     *
     * @type {!import("ol/Map").default}
     * @export
     */
    map: import("ol/Map").default;
    /**
     * The size, in map units, of a side of the extent.
     *
     * @type {number}
     * @export
     */
    extentSize: number;
    /**
     * @type {import('ngeo/map/FeatureOverlay').FeatureOverlay}
     * @private
     */
    private featuresOverlay_;
    /**
     * @type {!olCollection<Feature<import('ol/geom/Geometry').default>>}
     * @private
     */
    private overlayCollection_;
    /**
     * @type {?Polygon}
     * @private
     */
    private dataPolygon_;
    /**
     * Whether the current view is the extent selection.
     *
     * @type {boolean}
     * @export
     */
    selectingExtent: boolean;
    /**
     * Whether the current view is downloading one.
     *
     * @type {boolean}
     * @export
     */
    downloading: boolean;
    /**
     * The progression of the data loading (0-100%).
     *
     * @type {number}
     * @export
     */
    progressPercents: number;
    /**
     * Whether the menu is currently displayed.
     *
     * @type {boolean}
     * @export
     */
    menuDisplayed: boolean;
    /**
     * Whether the cancel download modal is displayed.
     *
     * @type {boolean}
     * @export
     */
    displayAlertAbortDownload: boolean;
    /**
     * Whether the load data modal is displayed.
     *
     * @type {boolean}
     * @export
     */
    displayAlertLoadData: boolean;
    /**
     * Whether the "no layer" modal is displayed.
     *
     * @type {boolean}
     * @export
     */
    displayAlertNoLayer: boolean;
    /**
     * Offline mask minimum margin in pixels.
     *
     * @type {number}
     * @export
     */
    maskMargin: number;
    /**
     * Minimum zoom where offline is enable.
     *
     * @type {number}
     * @export
     */
    minZoom: number;
    /**
     * Maximum zoom where offline is enable.
     *
     * @type {number}
     * @export
     */
    maxZoom: number;
    /**
     * Map view max zoom constraint.
     *
     * @type {number}
     * @export
     */
    originalMinZoom: number;
    /**
     * Map view min zoom constraint.
     *
     * @type {number}
     * @export
     */
    originalMaxZoom: number;
    /**
     * @type {number}
     * @export
     */
    estimatedLoadDataSize: number;
    /**
     * @type {boolean}
     */
    rotateMask: boolean;
    /**
     * @private
     * @param {import("ngeo/CustomEvent").default<{'progress': number}>} event the progress event.
     */
    private progressCallback_;
    $onInit(): void;
    $onDestroy(): void;
    /**
     * @returns {boolean} True if data are accessible offline.
     * @export
     */
    hasData(): boolean;
    /**
     * @export
     */
    computeSizeAndDisplayAlertLoadData(): void;
    /**
     * Toggle the selecting extent view.
     *
     * @param {boolean} [finished] If just finished downloading.
     * @export
     */
    toggleViewExtentSelection(finished?: boolean): void;
    /**
     * Validate the current extent and download data.
     *
     * @export
     */
    validateExtent(): void;
    /**
     * @private
     */
    private finishDownload_;
    /**
     * Ask to abort the download of data.
     *
     * @export
     */
    askAbortDownload(): void;
    /**
     * Abort the download of data.
     *
     * @export
     */
    abortDownload(): void;
    /**
     * Show the main menu.
     *
     * @export
     */
    showMenu(): void;
    /**
     * Activate offline mode.
     * Zoom to the extent of that data and restore the data.
     *
     * @export
     */
    activateOfflineMode(): void;
    /**
     *
     * Deactivate offline mode.
     * Reload the page.
     *
     * @export
     */
    deactivateOfflineMode(): void;
    /**
     * Toggle the visibility of the data's extent.
     *
     * @export
     */
    toggleExtentVisibility(): void;
    /**
     * @returns {boolean} True if the extent is currently visible. False otherwise.
     * @export
     */
    isExtentVisible(): boolean;
    /**
     * Delete the saved data.
     *
     * @export
     */
    deleteData(): void;
    /**
     * @private
     */
    private displayExtent_;
    /**
     * When enabling mask extent, zoom the view to the defined zoom range and
     * add constraints to the view to not allow user to move out of this range.
     *
     * @private
     */
    private addZoomConstraints_;
    /**
     * @private
     */
    private removeZoomConstraints_;
    /**
     * A polygon on the whole extent of the projection, with a hole for the offline extent.
     *
     * @param {import('ol/extent').Extent} extent An extent
     * @returns {Polygon} Polygon to save, based on the projection extent, the center of the map and
     *     the extentSize property.
     * @private
     */
    private createPolygonFromExtent_;
    /**
     * @returns {import('ol/extent').Extent} the download extent.
     * @private
     */
    private getDowloadExtent_;
    getExtentSize_(): number;
}
export namespace Controller {
    let $inject: string[];
}
export default myModule;
import angular from 'angular';
/**
 * @type {!angular.IModule}
 */
declare const myModule: angular.IModule;
