/**
 * Provides a service with print utility functions.
 *
 * @class
 * @ngdoc service
 * @ngname ngeoPrintUtils
 * @hidden
 */
export function PrintUtils(): void;
export class PrintUtils {
    /**
     * @type {number}
     */
    extentHalfHorizontalDistance_: number;
    /**
     * @type {number}
     */
    extentHalfVerticalDistance_: number;
    /**
     * Get the optimal print scale for a map, the map being defined by its
     * size (in pixels) and resolution (in map units per pixel).
     *
     * @param {import('ol/size').Size} mapSize Size of the map on the screen (px).
     * @param {number} mapResolution Resolution of the map on the screen.
     * @param {import('ol/size').Size} printMapSize Size of the map on the paper (dots).
     * @param {number[]} printMapScales Supported map scales on the paper.
     * The scales are provided as scale denominators, sorted in ascending order.
     * E.g. `[500, 1000, 2000, 4000]`.
     * @returns {number} The best scale. `-1` is returned if there is no optimal
     * scale, that is the optimal scale is lower than or equal to the first value
     * in `printMapScales`.
     */
    getOptimalScale(mapSize: import("ol/size").Size, mapResolution: number, printMapSize: import("ol/size").Size, printMapScales: number[]): number;
    /**
     * Get the optimal map resolution for a print scale and a map size.
     *
     * @param {import('ol/size').Size} mapSize Size of the map on the screen (px).
     * @param {import('ol/size').Size} printMapSize Size of the map on the paper (dots).
     * @param {number} printMapScale Map scale on the paper.
     * @returns {number} The optimal map resolution.
     */
    getOptimalResolution(mapSize: import("ol/size").Size, printMapSize: import("ol/size").Size, printMapScale: number): number;
    /**
     * Get the coordinates of the bottom left corner of the printed map.
     *
     * @param {import('ol/coordinate').Coordinate} mapCenter Center of the map to print.
     * @returns {import('ol/coordinate').Coordinate} The coordinates of the bottom left corner.
     */
    getBottomLeftCorner(mapCenter: import("ol/coordinate").Coordinate): import("ol/coordinate").Coordinate;
    /**
     * Get the coordinates of the bottom right corner of the printed map.
     *
     * @param {import('ol/coordinate').Coordinate} mapCenter Center of the map to print.ç
     * @returns {import('ol/coordinate').Coordinate} The coordinates of the bottom right corner.
     */
    getBottomRightCorner(mapCenter: import("ol/coordinate").Coordinate): import("ol/coordinate").Coordinate;
    /**
     * Get the coordinates of the up left corner of the printed map.
     *
     * @param {import('ol/coordinate').Coordinate} mapCenter Center of the map to print.
     * @returns {import('ol/coordinate').Coordinate} The coordinates of the up left corner.
     */
    getUpLeftCorner(mapCenter: import("ol/coordinate").Coordinate): import("ol/coordinate").Coordinate;
    /**
     * Get the coordinates of the up right corner of the printed map.
     *
     * @param {import('ol/coordinate').Coordinate} mapCenter Center of the map to print.
     * @returns {import('ol/coordinate').Coordinate} The coordinates of the up right corner.
     */
    getUpRightCorner(mapCenter: import("ol/coordinate").Coordinate): import("ol/coordinate").Coordinate;
}
/**
 * @hidden
 */
export const INCHES_PER_METER: 39.37;
/**
 * The rederance DPI in the PDF
 *
 * @hidden
 */
export const DOTS_PER_INCH: 72;
export default myModule;
/**
 * @type {angular.IModule}
 * @hidden
 */
declare const myModule: angular.IModule;
import angular from 'angular';
