export default VectorEncoder;
/**
 * @class
 * @hidden
 */
declare function VectorEncoder(): void;
declare class VectorEncoder {
    /**
     * @type {import('ol/format/GeoJSON').default}
     */
    geojsonFormat: import("ol/format/GeoJSON").default;
    /**
     * @param {import('ngeo/print/mapfish-print-v3').MapFishPrintLayer[]} mapFishPrintLayer Array.
     * @param {import('ol/layer/Vector').default<import('ol/source/Vector').default<import('ol/geom/Geometry').default>>} layer Layer.
     * @param {number} resolution Resolution.
     * @param {number} destinationPrintDpi The destination print DPI.
     * @param {number} [goodnessOfFit] Goodness of fit.
     */
    encodeVectorLayer(mapFishPrintLayer: import("ngeo/print/mapfish-print-v3").MapFishPrintLayer[], layer: import("ol/layer/Vector").default<import("ol/source/Vector").default<import("ol/geom/Geometry").default>>, resolution: number, destinationPrintDpi: number, goodnessOfFit?: number): void;
    /**
     * Transforms a style with a geometry to a new feature.
     *
     * @param {import('ol/style/Style').default} style Style.
     * @returns {olFeature<import('ol/geom/Geometry').default>} A feature from the style.
     */
    newFeatureFromStyle_(style: import("ol/style/Style").default): olFeature<import("ol/geom/Geometry").default>;
    /**
     * @param {string} geometryType Type of the GeoJSON geometry
     * @param {number} resolution Resolution.
     * @param {import('ol/style/Style').default} style Style.
     * @param {number} destinationPrintDpi The destination print DPI.
     * @param {number} [goodnessOfFit] Goodness of fit.
     * @returns {import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizer[]} The styles
     */
    encodeVectorStyle_(geometryType: string, resolution: number, style: import("ol/style/Style").default, destinationPrintDpi: number, goodnessOfFit?: number): import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizer[];
    /**
     * @param {import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizerPoint|import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizerPolygon} symbolizer
     *    MapFish Print symbolizer.
     * @param {import('ol/style/Fill').default} fillStyle Fill style.
     */
    encodeVectorStyleFill_(symbolizer: import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizerPoint | import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizerPolygon, fillStyle: import("ol/style/Fill").default): void;
    /**
     * @param {import('ol/style/Stroke').default} strokeStyle Stroke style.
     * @returns {import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizer} The style
     */
    encodeVectorStyleLine_(strokeStyle: import("ol/style/Stroke").default): import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizer;
    /**
     * @param {number} resolution Resolution.
     * @param {import('ol/style/Image').default} imageStyle Image style.
     * @param {number} destinationPrintDpi The destination print DPI.
     * @returns {import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizer} The style
     */
    encodeVectorStyle_Point_(resolution: number, imageStyle: import("ol/style/Image").default, destinationPrintDpi: number): import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizer;
    /**
     * @param {import('ol/style/Fill').default} fillStyle Fill style.
     * @param {import('ol/style/Stroke').default} strokeStyle Stroke style.
     * @returns {import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizer} The style
     */
    encodeVectorStylePolygon_(fillStyle: import("ol/style/Fill").default, strokeStyle: import("ol/style/Stroke").default): import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizer;
    /**
     * @param {import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizerPoint|import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizerLine|import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizerPolygon} symbolizer
     *      MapFish Print symbolizer.
     * @param {import('ol/style/Stroke').default} strokeStyle Stroke style.
     */
    encodeVectorStyleStroke_(symbolizer: import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizerPoint | import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizerLine | import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizerPolygon, strokeStyle: import("ol/style/Stroke").default): void;
    /**
     * @param {import('ol/style/Text').default} textStyle Text style.
     * @param {number} [goodnessOfFit] Goodness of fit.
     * @returns {import('ngeo/print/mapfish-print-v3').MapFishPrintSymbolizer} The style
     */
    encodeTextStyle_(textStyle: import("ol/style/Text").default, goodnessOfFit?: number): import("ngeo/print/mapfish-print-v3").MapFishPrintSymbolizer;
}
import olFeature from 'ol/Feature';
