/**
 * extends import('ngeo/rule/Rule').RuleOptions
 *
 * @typedef {Object} SelectOptions
 * @property {string[]} choices List of choices available for selection.
 * @property {boolean} [active=false] (RuleOptions)
 * @property {number|string} [expression] (RuleOptions)
 * @property {number|string|string[]} [literal] (RuleOptions)
 * @property {boolean} [isCustom] (RuleOptions)
 * @property {number} [lowerBoundary] (RuleOptions)
 * @property {string} name (RuleOptions)
 * @property {string} [operator] (RuleOptions)
 * @property {string[]} [operators] (RuleOptions)
 * @property {string} propertyName (RuleOptions)
 * @property {string} [type] (RuleOptions)
 * @property {number} [upperBoundary] (RuleOptions)
 */
/**
 * @hidden
 */
export default class _default extends ngeoRuleRule {
    /**
     * A select rule, which allows the selection of multiple values among a list
     * of choices.
     *
     * The literal property holds the list of selected choices, which is
     * comma-separated.
     *
     * @param {SelectOptions} options Options.
     */
    constructor(options: SelectOptions);
    /**
     * @type {string[]}
     * @private
     */
    private choices_;
    /**
     * @returns {string[]} Choices
     */
    get choices(): string[];
    /**
     * @returns {string[]} Selected choices
     */
    get selectedChoices(): string[];
}
/**
 * extends import('ngeo/rule/Rule').RuleOptions
 */
export type SelectOptions = {
    /**
     * List of choices available for selection.
     */
    choices: string[];
    /**
     * (RuleOptions)
     */
    active?: boolean;
    /**
     * (RuleOptions)
     */
    expression?: number | string;
    /**
     * (RuleOptions)
     */
    literal?: number | string | string[];
    /**
     * (RuleOptions)
     */
    isCustom?: boolean;
    /**
     * (RuleOptions)
     */
    lowerBoundary?: number;
    /**
     * (RuleOptions)
     */
    name: string;
    /**
     * (RuleOptions)
     */
    operator?: string;
    /**
     * (RuleOptions)
     */
    operators?: string[];
    /**
     * (RuleOptions)
     */
    propertyName: string;
    /**
     * (RuleOptions)
     */
    type?: string;
    /**
     * (RuleOptions)
     */
    upperBoundary?: number;
};
import ngeoRuleRule from 'ngeo/rule/Rule';
