/**
 * The options for creating a text style.
 *
 * extends import('ngeo/rule/Rule').RuleOptions
 *
 * @typedef {Object} TextOptions
 * @property {string} text
 * @property {number} [size]
 * @property {number} [angle]
 * @property {boolean} [rotateWithView=false]
 * @property {import('ol/color').Color} [color]
 * @property {number} [width]
 * @property {number} [offsetX]
 * @property {number} [offsetY]
 * @property {boolean} [exceedLength]
 * @property {boolean} [active=false] (RuleOptions)
 * @property {number|string} [expression] (RuleOptions)
 * @property {number|string|string[]} [literal] (RuleOptions)
 * @property {boolean} [isCustom] (RuleOptions)
 * @property {number} [lowerBoundary] (RuleOptions)
 * @property {string} name (RuleOptions)
 * @property {string} [operator] (RuleOptions)
 * @property {string[]} [operators] (RuleOptions)
 * @property {string} propertyName (RuleOptions)
 * @property {string} [type] (RuleOptions)
 * @property {number} [upperBoundary] (RuleOptions)
 */
/**
 * @hidden
 */
export default class _default extends ngeoRuleRule {
    /**
     * A text rule, which always compares the value with the LIKE operator, by default.
     *
     * @param {TextOptions} options Options.
     */
    constructor(options: TextOptions);
}
/**
 * The options for creating a text style.
 *
 * extends import('ngeo/rule/Rule').RuleOptions
 */
export type TextOptions = {
    text: string;
    size?: number;
    angle?: number;
    rotateWithView?: boolean;
    color?: import("ol/color").Color;
    width?: number;
    offsetX?: number;
    offsetY?: number;
    exceedLength?: boolean;
    /**
     * (RuleOptions)
     */
    active?: boolean;
    /**
     * (RuleOptions)
     */
    expression?: number | string;
    /**
     * (RuleOptions)
     */
    literal?: number | string | string[];
    /**
     * (RuleOptions)
     */
    isCustom?: boolean;
    /**
     * (RuleOptions)
     */
    lowerBoundary?: number;
    /**
     * (RuleOptions)
     */
    name: string;
    /**
     * (RuleOptions)
     */
    operator?: string;
    /**
     * (RuleOptions)
     */
    operators?: string[];
    /**
     * (RuleOptions)
     */
    propertyName: string;
    /**
     * (RuleOptions)
     */
    type?: string;
    /**
     * (RuleOptions)
     */
    upperBoundary?: number;
};
import ngeoRuleRule from 'ngeo/rule/Rule';
