/**
 * Service for streetview functionality with Mapillary
 */
declare class MapillaryService extends StreetviewService {
    /**
     * @param {angular.IScope} $scope Angular Scope.
     * @param {angular.ITimeoutService} $timeout Angular $timeout.
     * @param {angular.IHttpService} $http Angular $http service.
     * @param {?import('ol/Map').default} map The map.
     * @param {(newCoordinates: import('ol/coordinate').Coordinate | null) => void} handlePanoramaPositionChange Position change handler.
     * @param {string} accessToken The key to access the mapillary api.
     * @param {number} bufferSize The size to add to the bbox buffer.
     */
    constructor($scope: angular.IScope, $timeout: angular.ITimeoutService, $http: angular.IHttpService, map: import("ol/Map").default | null, handlePanoramaPositionChange: (newCoordinates: import("ol/coordinate").Coordinate | null) => void, accessToken: string, bufferSize: number);
    /**
     * @type {angular.ITimeoutService}
     * @private
     */
    private $timeout_;
    /**
     * Angular $http service.
     *
     * @private
     */
    private $http_;
    /**
     * The key to access the mapillary api.
     *
     * @private
     */
    private accessToken_;
    /**
     * The size of the buffer (in pixel) to add to the coordinate points to create the request bbox.
     *
     * @private
     */
    private bufferSizePx_;
    /**
     * Container of the mapillary viewer.
     */
    mapillaryElement: HTMLElement;
    Mapillary: typeof import("mapillary-js");
    mly: import("mapillary-js").Viewer;
    /**
     * @param {import('mapillary-js/src/viewer/events/ViewerImageEvent').ViewerImageEvent} evt
     */
    mapillaryEventHandler_: (evt: import("mapillary-js/src/viewer/events/ViewerImageEvent").ViewerImageEvent) => void;
    /**
     * Resize the image.
     */
    resize(): void;
    /**
     * @param {import("ol/extent.js").Extent} bbox A bounding box in LatLong projection
     * @returns {angular.IPromise<string>} Promise with the first imageId found or null.
     * @private
     */
    private searchImage_;
}
declare namespace MapillaryService {
    let $inject: string[];
}
export default MapillaryService;
import { StreetviewService } from './Service';
