/**
 * Abstract service for streetview
 *
 * @hidden
 */
export class StreetviewService {
    /**
     * @param {angular.IScope} $scope Scope.
     * @param {?import('ol/Map').default} map The map
     * @param {(newCoordinates: import('ol/coordinate').Coordinate | null) => void} handlePanoramePositionChange Position change handler. Executes the necessary changes in the component.
     */
    constructor($scope: angular.IScope, map: import("ol/Map").default | null, handlePanoramePositionChange: (newCoordinates: import("ol/coordinate").Coordinate | null) => void);
    scope_: import("angular").IScope;
    map_: import("ol/Map").default;
    handlePanoramaPositionChange_: (newCoordinates: import("ol/coordinate").Coordinate | null) => void;
    noDataAtLocation: boolean;
    /**
     * Get image for the given location.
     *
     * @param {import('ol/coordinate').Coordinate} coordinates Map view projection coordinates.
     */
    getPanorama(coordinates: import("ol/coordinate").Coordinate): void;
    /**
     * Toggle visibility of streetview / add or remove its event handler
     *
     * @param {boolean} show If the streetview is to show
     */
    toggleShow(show: boolean): void;
    /**
     * Set new position on the map.
     *
     * @param {import('ol/coordinate').Coordinate} newCoordinates array of longitude and latitude.
     */
    panoramaPositionChange(newCoordinates: import("ol/coordinate").Coordinate): void;
    /**
     * @param {import('ol/coordinate').Coordinate} lonLat LonLat coordinate.
     * @returns {import('ol/coordinate').Coordinate} Map view projection coordinate.
     */
    fromLonLat_(lonLat: import("ol/coordinate").Coordinate): import("ol/coordinate").Coordinate;
    /**
     * @param {import('ol/coordinate').Coordinate} coordinate Map view projection coordinate.
     * @returns {import('ol/coordinate').Coordinate} LonLat coordinate.
     */
    toLonLat_(coordinate: import("ol/coordinate").Coordinate): import("ol/coordinate").Coordinate;
    /**
     * @param {import("ol/extent.js").Extent} extent Extent in EPSG:2056 to reproject.
     * @returns {import("ol/extent.js").Extent} LonLat extent.
     */
    extentToLonLat_(extent: import("ol/extent.js").Extent): import("ol/extent.js").Extent;
}
