import { BehaviorSubject } from 'rxjs';
import OlMap from 'ol/Map';
/**
 * Object used to expose the OpenLayer map.
 *
 * Example of usage:
 * ```js
 *    (window as any).gmfapi.store.map.getMap().subscribe({
 *      next: (map: Map) => {
 *        if (map) {
 *          ...
 *        }
 *      },
 *    })
 * ```
 */
export declare class MapModel {
    /**
     * The observable map's properties.
     *
     * @private
     */
    map_: BehaviorSubject<OlMap>;
    /**
     * @returns the OpenLayers map.
     */
    getMap(): BehaviorSubject<OlMap>;
    /**
     * Set the OpenLayers map.
     *
     * @param map the OpenLayers map
     */
    setMap(map: OlMap): void;
}
declare const map: MapModel;
export default map;
